@@ -18,21 +18,29 @@
 """Utilities for using and training tokenizers (char, wordpiece, sentencepiece)"""
 
 import logging
+
 logger = logging.getLogger(__name__)
 import sentencepiece as spm
 
 
 class SentencePieceTokenizer(object):
+
     def __init__(self, model_path):
         self.sp_model = spm.SentencePieceProcessor()
         self.sp_model.Load(model_path)
+        # vocab = self.get_vocab()
+        # print(vocab["<|endoftext|>"])
+        # print(vocab["<|endofpiece|>"])
 
     @property
     def vocab_size(self):
         return self.sp_model.GetPieceSize()
 
     def get_vocab(self):
-        vocab = {self.convert_id_to_token(i): i for i in range(self.vocab_size)}
+        vocab = {
+            self.convert_id_to_token(i): i
+            for i in range(self.vocab_size)
+        }
         # vocab.update(self.added_tokens_encoder)
         return vocab
 
@@ -49,7 +57,7 @@ class SentencePieceTokenizer(object):
         return self.sp_model.IdToPiece(int(idx))
 
     def convert_ids_to_tokens(self, idxs):
-        return [self.sp_model.IdToPiece(idx) for idx in idxs]
+        return [self.sp_model.IdToPiece(int(idx)) for idx in idxs]
 
     def convert_tokens_to_string(self, tokens, all_command_token={}):
         """Converts a sequence of tokens (string) in a single string."""
@@ -58,10 +66,10 @@ class SentencePieceTokenizer(object):
         for token in tokens:
             # make sure that special tokens are not decoded using sentencepiece model
             if token in all_command_token:
-                out_string += self.sp_model.decode_pieces(current_sub_tokens) + token + " "
+                out_string += self.sp_model.decode_pieces(
+                    current_sub_tokens) + token + " "
                 current_sub_tokens = []
             else:
                 current_sub_tokens.append(token)
         out_string += self.sp_model.decode_pieces(current_sub_tokens)
         return out_string.strip()
-
