@@ -5,10 +5,11 @@ from sklearn.linear_model import HuberRegressor
 from torch.nn import Module
 import torch
 import json
-from typing import Union 
+from typing import Union
 from flagai.model.file_utils import _get_model_id, _get_config_path, _get_checkpoint_path, _get_vocab_path, _get_model_files
 import os
 
+
 # The base model for models
 class BaseModel(Module):
 
@@ -39,6 +40,26 @@ class BaseModel(Module):
             args['checkpoint_activations'] = False
         return cls(args, **kwargs)
 
+    @classmethod
+    def _load_state_dict_into_model(cls,
+                                    model,
+                                    pretrained_model_name_or_path,
+                                    verbose=False):
+        pl_sd = torch.load(pretrained_model_name_or_path, map_location="cpu")
+        sd = pl_sd["state_dict"]
+        if "global_step" in pl_sd:
+            print(f"Global Step: {pl_sd['global_step']}")
+        m, u = model.load_state_dict(sd, strict=False)
+        if len(m) > 0 and verbose:
+            print("missing keys:")
+            print(m)
+        if len(u) > 0 and verbose:
+            print("unexpected keys:")
+            print(u)
+        model.cuda()
+        model.eval()
+        return model
+
     @classmethod
     def from_pretrain(cls,
                       download_path='./checkpoints/',
@@ -48,8 +69,10 @@ class BaseModel(Module):
                       **kwargs):
         model_id = None
 
+        raw_download_path = download_path
         # Try load model from local path
         download_path = os.path.join(download_path, model_name)
+
         config_path = os.path.join(download_path, "config.json")
         checkpoint_path = os.path.join(download_path, "pytorch_model.bin")
 
@@ -72,8 +95,9 @@ class BaseModel(Module):
                     if model_parallel_size > 1 and not check_pytorch_model_mp_size(
                             download_path, model_parallel_size):
                         brief_model_name = MODEL_DICT[model_name.lower()][2]
-                        change_pytorch_model_mp_from_1_to_n_new(brief_model_name,
-                            download_path, model_parallel_size)
+                        change_pytorch_model_mp_from_1_to_n_new(
+                            brief_model_name, download_path,
+                            model_parallel_size)
 
                 from flagai import mpu
                 torch.distributed.barrier(group=mpu.get_model_parallel_group())
@@ -90,7 +114,33 @@ class BaseModel(Module):
                     model.load_weights(checkpoint_path)
             return model
 
-        if os.path.exists(config_path):
+        def load_diffusion_local(yaml_path):
+            """
+            Now only diffusion models requires yaml
+            """
+            from omegaconf import OmegaConf
+            checkpoint_path = os.path.join(
+                download_path, "model.ckpt")  # Specific to diffusion models
+
+            config = OmegaConf.load(f"{yaml_path}")
+            model_config = config.model
+            model_config.params.cond_stage_config.params.download_path = raw_download_path
+
+            model = cls(**model_config.get("params", dict()))
+
+            model = cls._load_state_dict_into_model(
+                model,
+                checkpoint_path,
+            )
+            return model
+
+        yaml_path = os.path.join(download_path, "config.yaml")
+        if os.path.exists(yaml_path):
+            """
+            Now only diffusion models requires yaml
+            """
+            return load_diffusion_local(yaml_path)
+        elif os.path.exists(config_path):
             """
             It is fine when checkpoint_path does not exist, for the case that only_download_config=True
             At that time the model will not be loaded. 
@@ -111,7 +161,8 @@ class BaseModel(Module):
                 if not file_name.endswith("bin"):
                     _get_vocab_path(download_path, file_name, model_id)
 
-            if not only_download_config and os.path.exists(os.path.join(download_path, 'config.json')):
+            if not only_download_config and os.path.exists(
+                    os.path.join(download_path, 'config.json')):
                 if os.getenv('ENV_TYPE') == 'deepspeed+mpu':
                     model_parallel_size = int(os.getenv("MODEL_PARALLEL_SIZE"))
                     if model_parallel_size > 1:
@@ -129,25 +180,48 @@ class BaseModel(Module):
                     # Only to download the model slices(megatron-lm).
                     for file_to_load in model_files:
                         if "pytorch_model_" in file_to_load:
-                            _get_checkpoint_path(download_path,
-                                                 file_to_load,
+                            _get_checkpoint_path(download_path, file_to_load,
                                                  model_id)
 
                 elif 'pytorch_model.bin' in model_files:
-                    checkpoint_path = _get_checkpoint_path(download_path,
-                                                           'pytorch_model.bin',
-                                                           model_id)
-                else :
+                    checkpoint_path = _get_checkpoint_path(
+                        download_path, 'pytorch_model.bin', model_id)
+                else:
                     checkpoint_merge = {}
                     # maybe multi weights files
                     for file_to_load in model_files:
                         if "pytorch_model-0" in file_to_load:
-                            _get_checkpoint_path(download_path,
-                                                 file_to_load,
+                            _get_checkpoint_path(download_path, file_to_load,
                                                  model_id)
-                            checkpoint_to_load = torch.load(os.path.join(download_path, file_to_load), map_location="cpu")
+                            checkpoint_to_load = torch.load(os.path.join(
+                                download_path, file_to_load),
+                                                            map_location="cpu")
                             for k, v in checkpoint_to_load.items():
                                 checkpoint_merge[k] = v
                     # save all parameters
-                    torch.save(checkpoint_merge, os.path.join(download_path, "pytorch_model.bin"))
+                    torch.save(
+                        checkpoint_merge,
+                        os.path.join(download_path, "pytorch_model.bin"))
+        if os.path.exists(yaml_path):
+            return load_diffusion_local(yaml_path)
         return load_local(checkpoint_path)
+
+    @classmethod
+    def download(cls,
+                download_path='./checkpoints/',
+                model_name='RoBERTa-base-ch',
+                **kwargs):
+        try:
+            model_id = _get_model_id(model_name)
+        except:
+            print("Model hub is not reachable!")
+        # prepare the download path
+        # downloading the files
+        if model_id and model_id != "null":
+            model_files = eval(_get_model_files(model_name))
+            print("model files:" + str(model_files))
+            for file_name in model_files:
+                if not file_name.endswith("bin"):
+                    _get_vocab_path(os.path.join(download_path, model_name), file_name, model_id)
+                else :
+                    _get_checkpoint_path(os.path.join(download_path, model_name), file_name, model_id)
\ No newline at end of file
